@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "taskpaper-mode" "1.0"
-  "Major mode for working with TaskPaper files."
-  ()
+(define-package "taskpaper-mode" "20250823.1538"
+  "Major mode for TaskPaper files."
+  '((emacs "25.1"))
   :url "https://github.com/saf-dmitry/taskpaper-mode"
-  :commit "169dab1eb632e5ac5e34608be2df4e9854368180"
-  :revdesc "169dab1eb632"
+  :commit "208e6832ca68b33263440c472386ca033ba2735c"
+  :revdesc "208e6832ca68"
   :keywords '("outlines" "notetaking" "task management" "productivity" "taskpaper")
   :authors '(("Dmitry Safronov" . "saf.dmitry@gmail.com"))
   :maintainers '(("Dmitry Safronov" . "saf.dmitry@gmail.com")))
